@@ -1365,78 +1365,6 @@ int32_t SPVM__Sys__IO__fcntl(SPVM_ENV* env, SPVM_VALUE* stack) {
 #endif
 }
 
-int32_t SPVM__Sys__IO__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  int32_t error_id = 0;
-  
-  void* obj_stream = stack[0].oval;
-  if (!obj_stream) {
-    return env->die(env, stack, "$stream must be defined", __func__, FILE_NAME, __LINE__);
-  }
-
-  FILE* stream = (FILE*)env->get_pointer(env, stack, obj_stream);
-
-  int32_t scope_id = env->enter_scope(env, stack);
-  
-  int32_t capacity = 80;
-  void* obj_buf = env->new_string(env, stack, NULL, capacity);
-  int8_t* buf = env->get_elems_byte(env, stack, obj_buf);
-  
-  int32_t pos = 0;
-  int32_t end_is_eof = 0;
-  while (1) {
-    int32_t ch = fgetc(stream);
-    if (ch == EOF) {
-      end_is_eof = 1;
-      break;
-    }
-    else {
-      if (pos >= capacity) {
-        // Extend buf capacity
-        int32_t new_capacity = capacity * 2;
-        void* new_object_buf = env->new_string(env, stack, NULL, new_capacity);
-        int8_t* new_buf = env->get_elems_byte(env, stack, new_object_buf);
-        memcpy(new_buf, buf, capacity);
-        
-        int32_t removed = env->remove_mortal(env, stack, scope_id, obj_buf);
-        
-        capacity = new_capacity;
-        obj_buf = new_object_buf;
-        buf = new_buf;
-      }
-      
-      if (ch == '\n') {
-        buf[pos] = ch;
-        pos++;
-        break;
-      }
-      else {
-        buf[pos] = ch;
-        pos++;
-      }
-    }
-  }
-  
-  if (pos > 0 || !end_is_eof) {
-    void* oline;
-    if (pos == 0) {
-      oline = env->new_string(env, stack, NULL, 0);
-    }
-    else {
-      oline = env->new_string(env, stack, NULL, pos);
-      int8_t* line = env->get_elems_byte(env, stack, oline);
-      memcpy(line, buf, pos);
-    }
-    
-    stack[0].oval = oline;
-  }
-  else {
-    stack[0].oval = NULL;
-  }
-  
-  return 0;
-}
-
 int32_t SPVM__Sys__IO__ftruncate(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t fd = stack[0].ival;
