@@ -20,19 +20,25 @@ This is a L<pointer class|SPVM::Document::Language/"Pointer Class">.
 
 =over 2
 
-=item L<Sys::Socket::Sockaddr::Interface|SPVM::Sys::Socket::Sockaddr::Interface>
-
 =item L<Cloneable|SPVM::Cloneable>
 
 =back
 
+=head1 Class Methods
+
+=head2 new
+
+  static method new : Sys::Socket::Sockaddr::In ();
+
+Create a new C<Sys::Socket::Sockaddr> object.
+
 =head1 Instance Methods
 
-=head2 has_interfaces
+=head2 DESTROY
 
-  required method has_interfaces : int ();
+  method DESTROY : void ();
 
-Retruns C<1>.
+The destructor.
 
 =head2 sa_family
 
@@ -40,18 +46,32 @@ Retruns C<1>.
 
 Gets C<sa_family>.
 
+=head2 set_sa_family
+
+  method sa_family : int ()
+
+Sets C<sa_family>.
+
 =head2 sizeof
 
-  method sizeof : int ()
+  method size : int ()
 
-The size of the structure internally used.
+Returns the size of the structure. This method is planed to be implemented in a child class.
 
+Exception:
+
+  Not implemented.
+  
 =head2 clone
 
   method clone : Sys::Socket::Sockaddr ();
 
-Clones this object.
+Clones this object. This method is planed to be implemented in a child class.
 
+Exception:
+
+  Not implemented.
+  
 =head1 Well Known Child Classes
 
 =over 2
